Learn R Programming

QPmin (version 0.5-1)

QPgen.internal.convex: QPgen.internal.convex

Description

Generates a separable convex quadratic problem of the form $$ \min_x \frac{1}{2} x^T G x + x^T g $$ $$ Ax \geq b $$

Usage

QPgen.internal.convex(m, alphas, rhos, omegas)

Arguments

m

Integer parameter controlling the number of variables (2m) and constraints (3m) for the generated problem.

alphas

m parameters taking values between 5 and 7.5.

rhos

m parameters taking values in {0, 1}.

omegas

m parameters taking values in {0, 1}.

Value

G

The quadratic component of the objective function.

g

The linear component of the objective function

A

The constraints coefficient matrix. This matrix has 3m rows and 2m columns.

b

The vector with the lower bounds on the constraints.

opt

An approximate expected value at the optimum solutions.

globals

A list containing all of the global solutions to the problem.

Details

The problem has a unique global minimum and the constraints are linearly independent at all of the solutions.

References

``A new technique for generating quadratic programming test problems,'' Calamai P.H., L.N. Vicente, and J.J. Judice, Mathematical Programming 61 (1993), pp. 215-231.

Examples

Run this code
# NOT RUN {
m <- 3
alphas <-  runif(m, min = 5, max = 7.4999)
rhos <- round(runif(m))
omegas <- round(runif(m))
QPgen.internal.convex(m, alphas, rhos, omegas)
# }

Run the code above in your browser using DataLab