Learn R Programming

QPmin (version 0.5-1)

QPmin-package: QPmin

Description

QPmin

Arguments

Details

The DESCRIPTION file: QPmin QPmin Active Set Method (ASM) for minimizinig indefinite quadratic programs subject to linear constraints: QPmin. The package also provide a set of additional functions for the random generation of specific quadratic programs.

References

``A new technique for generating quadratic programming test problems,'' Calamai P.H., L.N. Vicente, and J.J. Judice, Mathematical Programming 61 (1993), pp. 215-231.

``A General Quadratic Programming Algorithm,'' Fletcher, R., IMA Journal of Applied Mathematics 7 (1971), pp. 76-91.

``An Algorithm for Large-Scale Quadratic Programming,'' Gould, N.I.M., IMA Journal of Numerical Analysis 11 (1991), pp. 299-324.

``A Stabilization of the Simplex Method,'' Bartels, R.H., Numerische Mathematik 16 (1971), pp. 414-434.

Examples

Run this code
# NOT RUN {
set.seed(2)
RP <- randomQP(8, "indefinite")
with(RP, QPmin(G, g, t(A), b, neq = 0, tol = 1e-8))
# }

Run the code above in your browser using DataLab