Generates a separable bilinear problem of the form
$$
\min_x \frac{1}{2} x^T G x + x^T g
$$
$$
Ax \geq b
$$
Usage
QPgen.internal.bilinear(m, alphas)
Arguments
m
Integer parameter controlling the number of variables (2m) and
constraints (3m) for the generated problem.
alphas
m positive parameters.
Value
G
The quadratic component of the objective function.
g
The linear component of the objective function
A
The constraints coefficient matrix. This matrix has 3m rows and 2m columns.
b
The vector with the lower bounds on the constraints.
opt
An approximate expected value at the optimum solutions.
globals
A list containing all of the global solutions to the problem.
Details
The problem is an indefinite problem with 2^m local minima of which 2^n
are global. Here, n is equal to the number of alphas exactly equal to 0.5. The
constraints are guaranteed independent only at each solution, but not generally
everywhere in the feasible region.
References
``A new technique for generating quadratic programming test problems,'' Calamai P.H., L.N. Vicente, and J.J. Judice, Mathematical Programming 61 (1993), pp. 215-231.